summaryrefslogtreecommitdiffstats
path: root/kbugbuster/gui/cwbuglistcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbugbuster/gui/cwbuglistcontainer.h')
-rw-r--r--kbugbuster/gui/cwbuglistcontainer.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kbugbuster/gui/cwbuglistcontainer.h b/kbugbuster/gui/cwbuglistcontainer.h
index bcda4c15..9dd1d9bd 100644
--- a/kbugbuster/gui/cwbuglistcontainer.h
+++ b/kbugbuster/gui/cwbuglistcontainer.h
@@ -20,7 +20,7 @@
#include "package.h"
#include "bug.h"
-#include <qwidget.h>
+#include <tqwidget.h>
class KListView;
class KFind;
@@ -40,28 +40,28 @@ class CWBugListContainer : public QWidget
Q_OBJECT
public:
- CWBugListContainer( QWidget* parent = 0, const char* name = 0 );
+ CWBugListContainer( TQWidget* parent = 0, const char* name = 0 );
~CWBugListContainer();
- void setBugList( const Package &package, const QString &component, const Bug::List &bugs );
+ void setBugList( const Package &package, const TQString &component, const Bug::List &bugs );
/**
* Overloaded method that takes a QString for the label. To be used when the
* bug list doesn't belong to a package, liek search results
*/
- void setBugList( const QString &label, const Bug::List &bugs );
+ void setBugList( const TQString &label, const Bug::List &bugs );
- void searchBugByTitle( int options, const QString& pattern );
+ void searchBugByTitle( int options, const TQString& pattern );
/** Return list of selected bugs in the listview. Used for merging. */
- QStringList selectedBugs() const;
+ TQStringList selectedBugs() const;
public slots:
void setNoList();
- void setLoading( const Package &package, const QString &component );
- void setLoading( const QString &label );
+ void setLoading( const Package &package, const TQString &component );
+ void setLoading( const TQString &label );
void setCacheMiss( const Package &package );
- void setCacheMiss( const QString &label );
+ void setCacheMiss( const TQString &label );
void slotFindNext();
signals:
@@ -72,17 +72,17 @@ signals:
void currentChanged( const Bug & );
private slots:
- void execute( QListViewItem * );
- void changeCurrent( QListViewItem * );
+ void execute( TQListViewItem * );
+ void changeCurrent( TQListViewItem * );
void markBugCommand( BugCommand * );
- void clearCommand( const QString & );
+ void clearCommand( const TQString & );
- void searchHighlight( const QString &, int, int );
+ void searchHighlight( const TQString &, int, int );
private:
- QLabel *m_listLabel;
- QWidgetStack *m_listStack;
+ TQLabel *m_listLabel;
+ TQWidgetStack *m_listStack;
KListView *m_listBugs;
KFind *m_find;
@@ -40,28 +40,28 @@ class CWBugListContainer : public QWidget
/**
- * Overloaded method that takes a QString for the label. To be used when the
+ * Overloaded method that takes a TQString for the label. To be used when the
* bug list doesn't belong to a package, liek search results
*/